@@ -8,6 +8,7 @@ from tqdm import tqdm
 from hover import module_config
 from hover.core import Loggable
 from bokeh.models import Button, Dropdown, ColumnDataSource, DataTable, TableColumn
+from .local_config import dataset_help_widget
 
 
 class SupervisableDataset(Loggable):
@@ -53,6 +54,7 @@ class SupervisableDataset(Loggable):
         - param feature_key: key in each piece of dict mapping to the feature.
         - param label_key: key in each piece of dict mapping to the ground truth in STRING form.
         """
+        self._info("Initializing...")
 
         def dictl_transform(dictl, labels=True):
             """
@@ -96,6 +98,7 @@ class SupervisableDataset(Loggable):
         self.setup_widgets()
         # self.setup_label_coding() # redundant if setup_pop_table() immediately calls this again
         self.setup_pop_table(width_policy="fit", height_policy="fit")
+        self._good("Finished initialization.")
 
     def copy(self, use_df=True):
         """
@@ -165,6 +168,8 @@ class SupervisableDataset(Loggable):
         self.data_committer.on_click(commit_base_callback)
         self.dedup_trigger.on_click(dedup_base_callback)
 
+        self.help_div = dataset_help_widget()
+
     def view(self):
         """
         Defines the layout of bokeh models.
@@ -173,6 +178,7 @@ class SupervisableDataset(Loggable):
         from bokeh.layouts import row, column
 
         return column(
+            self.help_div,
             row(self.update_pusher, self.data_committer, self.dedup_trigger),
             self.pop_table,
         )
@@ -242,7 +248,7 @@ class SupervisableDataset(Loggable):
             f"Subscribed {explorer.__class__.__name__} to dataset commits: {subset_mapping}"
         )
 
-    def setup_label_coding(self):
+    def setup_label_coding(self, verbose=True, debug=False):
         """
         Auto-determine labels in the dataset, then create encoder/decoder in lexical order.
         Add ABSTAIN as a no-label placeholder.
@@ -262,8 +268,12 @@ class SupervisableDataset(Loggable):
         }
         self.label_decoder = {_v: _k for _k, _v in self.label_encoder.items()}
 
-        self._good(f"Set up label encoder/decoder with {len(self.classes)} classes.")
-        self.validate_labels()
+        if verbose:
+            self._good(
+                f"Set up label encoder/decoder with {len(self.classes)} classes."
+            )
+        if debug:
+            self.validate_labels()
 
     def validate_labels(self, raise_exception=True):
         """
@@ -304,11 +314,12 @@ class SupervisableDataset(Loggable):
             self.setup_label_coding()
 
             # re-compute label population
-            pop_data = dict(label=self.classes)
+            eff_labels = [module_config.ABSTAIN_DECODED, *self.classes]
+            pop_data = dict(label=eff_labels)
             for _subset in subsets:
                 _subpop = self.dfs[_subset]["label"].value_counts()
                 pop_data[f"count_{_subset}"] = [
-                    _subpop.get(_label, 0) for _label in self.classes
+                    _subpop.get(_label, 0) for _label in eff_labels
                 ]
 
             # push results to bokeh data source
@@ -319,7 +330,8 @@ class SupervisableDataset(Loggable):
             )
 
         update_population()
-        self.update_pusher.on_click(update_population)
+        self.data_committer.on_click(update_population)
+        self.dedup_trigger.on_click(update_population)
 
     def df_deduplicate(self):
         """
@@ -422,7 +434,6 @@ class SupervisableDataset(Loggable):
             (trans_subset, trans_embedding),
         ]:
             # edge case: embedding is too small
-            print(_embedding.shape)
             if _embedding.shape[0] < 1:
                 for _key in _subset:
                     assert (
